@@ -1,5 +1,5 @@
 package Git::Repository;
-$Git::Repository::VERSION = '1.314';
+$Git::Repository::VERSION = '1.316';
 use warnings;
 use strict;
 use 5.006;
@@ -282,20 +282,12 @@ sub version_ge {
 
 1;
 
-# ABSTRACT: Perl interface to Git repositories
-
 __END__
 
-=pod
-
 =head1 NAME
 
 Git::Repository - Perl interface to Git repositories
 
-=head1 VERSION
-
-version 1.314
-
 =head1 SYNOPSIS
 
     use Git::Repository;
@@ -451,12 +443,18 @@ pointing to it, simply do it in two steps:
     # on the resulting repository
     $r = Git::Repository->new( ... );
 
+
 =head1 METHODS
 
-=for Pod::Coverage     create
+=begin Pod::Coverage
+
+    create
     repo_path
     wc_path
 
+=end Pod::Coverage
+
+
 L<Git::Repository> supports the following methods:
 
 =head2 command
@@ -667,6 +665,7 @@ Although it supports C<git init> and C<git clone>
 porcelain commands, and provides no way to control bidirectional commands
 (such as C<git commit-tree>).
 
+
 =head2 Git::Wrapper
 
 L<Git::Wrapper>
@@ -710,6 +709,7 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Git::Repository
 
+
 You can also look for information at:
 
 =over 4
@@ -732,23 +732,9 @@ L<http://search.cpan.org/dist/Git-Repository>
 
 =back
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Git-Repository or by email to
-bug-git-repository@rt.cpan.org.
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHOR
-
-Philippe Bruhat (BooK) <book@cpan.org>
-
 =head1 COPYRIGHT
 
-Copyright 2010-2014 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2010-2015 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
