@@ -1,5 +1,5 @@
 package Git::Repository::Plugin;
-$Git::Repository::Plugin::VERSION = '1.312';
+$Git::Repository::Plugin::VERSION = '1.316';
 use strict;
 use warnings;
 use 5.006;
@@ -30,20 +30,12 @@ sub _keywords {
 
 1;
 
-# ABSTRACT: Base class for Git::Repository plugins
-
-
 __END__
-=pod
 
 =head1 NAME
 
 Git::Repository::Plugin - Base class for Git::Repository plugins
 
-=head1 VERSION
-
-version 1.312
-
 =head1 SYNOPSIS
 
     package Git::Repository::Plugin::Hello;
@@ -112,23 +104,9 @@ team.
 
 Further improvements to the plugin system proposed by Aristotle Pagaltzis.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Git-Repository or by email to
-bug-git-repository@rt.cpan.org.
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHOR
-
-Philippe Bruhat (BooK) <book@cpan.org>
-
 =head1 COPYRIGHT
 
-Copyright 2010-2014 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2010-2015 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
@@ -136,4 +114,3 @@ This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
-
